@@ -64,6 +64,8 @@ __all__ = (
     "TrafficRoutingTypeType",
     "TriggerEventTypeType",
     "ServiceName",
+    "PaginatorName",
+    "WaiterName",
 )
 
 
@@ -464,3 +466,15 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "list_application_revisions",
+    "list_applications",
+    "list_deployment_configs",
+    "list_deployment_groups",
+    "list_deployment_instances",
+    "list_deployment_targets",
+    "list_deployments",
+    "list_git_hub_account_token_names",
+    "list_on_premises_instances",
+]
+WaiterName = Literal["deployment_successful"]
